.. _rockstar:

*******************
Rockstar catalogues
*******************

The folder ``Rockstar`` contains the Rockstar halo and subhalo catalogues. The data is organized following the general hierarchical structure described in :ref:`suite_folders`.

The format of the catalogues is the traditional one from Rockstar, and we refer the user to the `Rockstar documentation <https://bitbucket.org/gfcstanford/rockstar/src/main/>`_ for further details. We note that for the hydrodynamic simulations, Rockstar has been run using the version that account for components other dark matter such as gas, stars, and black-holes.

We also release the merger trees constructed through consistent trees. We refer the reader to the `consistent trees documentation <https://bitbucket.org/pbehroozi/consistent-trees/src/main/>`_ for details on the format of the files.
